@@ -293,7 +293,7 @@ class CameraModelForm(autocomplete.FutureModelForm):
                      ),
             Fieldset('Flash',
                      'int_flash',
-                     'int_flash_gn',
+                     AppendedText('int_flash_gn', 'm'),
                      'ext_flash',
                      'pc_sync',
                      'shoe',
@@ -488,7 +488,7 @@ class FlashModelForm(ModelForm):
                      'manufacturer',
                      'model',
                      'disambiguation',
-                     'guide_number',
+                     AppendedText('guide_number', 'm'),
                      'gn_info',
                      AppendedText('trigger_voltage', 'V'),
                      ),
